@@ -14,6 +14,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import re
+
 from django import forms as django_forms
 from django.utils import html
 from django.utils.translation import ugettext_lazy as _  # noqa
@@ -33,22 +35,27 @@ class ExpressionWidget(forms.Widget):
     def render(self, name, value, attrs):
         final_attrs = self.build_attrs(attrs, name=name)
         final_attrs['placeholder'] = _('Add a dimension')
-        if 'all' in self.initial['service']:
-            dim = ''
+        if value:
+            dim = value
         else:
-            dim = next(("%s=%s" % (k, v) for k, v in self.initial.items()), '')
+            if 'all' in self.initial['service']:
+                dim = ''
+            else:
+                dim = next(("%s=%s" % (k, v) for k, v in self.initial.items()), '')
         final_attrs['service'] = dim
         output = '''
         <div ng-controller="alarmEditController" ng-init="init('%(service)s')">
          <input type="hidden" name="%(name)s" id="dimension"/>
-         <select id="metric-chooser" class="form-control" ng-model="currentMetric"
+         <select id="metric-chooser" class="form-control"
+          ng-model="currentMetric"
           ng-options="metric.name for metric in metrics | orderBy:'name'"
           ng-change="metricChanged()"></select>
          <tags-input id="dimension-chooser" ng-model="tags"
           placeholder="%(placeholder)s"
-          add-from-autocomplete-only="true" max-results-to-show="20"
+          add-from-autocomplete-only="true"
           on-tag-added="saveDimension()" on-tag-removed="saveDimension()">
-          <auto-complete source="possibleDimensions()" min-length="1">
+          <auto-complete source="possibleDimensions()"
+          max-results-to-show="30" min-length="1">
           </auto-complete>
          </tags-input>
         </div>
@@ -70,7 +77,10 @@ class SimpleExpressionWidget(django_forms.MultiWidget):
         super(SimpleExpressionWidget, self).__init__(_widgets, attrs)
 
     def decompress(self, expr):
-        return [None, None, None]
+        if expr:
+            return re.search('^(\w+)\((.*)\) ([<>=]*) (.*)$', expr).groups()
+        else:
+            return [None, None, None, None]
 
     def format_output(self, rendered_widgets):
         return ''.join(rendered_widgets)
